| /llvm-project-15.0.7/clang/test/SemaCUDA/ |
| H A D | function-template-overload.cu | 13 template <typename T> __device__ DType overload_h_d(T a) { return DType(); } in overload_h_d() 18 template __device__ __host__ DType overload_h_d(int a); // There's no HD template... 22 template __device__ DType overload_h_d(int a); // OK. instantiates D 26 template <> __device__ __host__ DType overload_h_d(long a); // There's no HD template... 30 template <> __device__ DType overload_h_d(long a); // OK. instantiates D 58 …plate <typename T1, typename T2 = int> __device__ DType overload_h_d2(T1 a) { T1 x; T2 y; return D… in overload_h_d2() 95 …DType d = overload_h_d(20); // expected-error {{no viable conversion from 'HType' to 'DTy… in hf() 96 …DType d2i = overload_h_d2<int>(21); // expected-error {{no viable conversion from 'HType' to 'DTy… in hf() 110 DType d = overload_h_d(20); in df() 111 DType d2i = overload_h_d2<int>(21); in df() [all …]
|
| /llvm-project-15.0.7/mlir/test/Integration/Dialect/SparseTensor/taco/tools/ |
| H A D | mlir_pytaco_api.py | 27 dtype = mlir_pytaco.DType 38 int8 = mlir_pytaco.DType(mlir_pytaco.Type.INT8) 39 int16 = mlir_pytaco.DType(mlir_pytaco.Type.INT16) 40 int32 = mlir_pytaco.DType(mlir_pytaco.Type.INT32) 41 int64 = mlir_pytaco.DType(mlir_pytaco.Type.INT64) 42 float16 = mlir_pytaco.DType(mlir_pytaco.Type.FLOAT16) 43 float32 = mlir_pytaco.DType(mlir_pytaco.Type.FLOAT32) 44 float64 = mlir_pytaco.DType(mlir_pytaco.Type.FLOAT64) 45 complex64 = mlir_pytaco.DType(mlir_pytaco.Type.COMPLEX64) 46 complex128 = mlir_pytaco.DType(mlir_pytaco.Type.COMPLEX128)
|
| H A D | mlir_pytaco_io.py | 26 DType = mlir_pytaco.DType variable 35 dtype: DType = DType(Type.FLOAT32)) -> Tensor: argument
|
| H A D | mlir_pytaco.py | 95 class DType: class 157 return DType(nptype_to_dtype[ty]) 520 def dtype(self) -> DType: 810 def dtype(self) -> DType: 889 dst_dtype: DType 1209 dtype: DType, argument 1247 dtype: DType, argument 1296 def dtype(self) -> DType: 1675 def dtype(self) -> DType: 1752 def dtype(self) -> DType: [all …]
|
| /llvm-project-15.0.7/llvm/bindings/ocaml/debuginfo/ |
| H A D | debuginfo_ocaml.c | 812 value llvm_di_type_get_name(LLVMMetadataRef DType) { in llvm_di_type_get_name() argument 814 const char *Name = LLVMDITypeGetName(DType, &Len); in llvm_di_type_get_name() 818 value llvm_di_type_get_size_in_bits(LLVMMetadataRef DType) { in llvm_di_type_get_size_in_bits() argument 819 uint64_t Size = LLVMDITypeGetSizeInBits(DType); in llvm_di_type_get_size_in_bits() 824 uint64_t Size = LLVMDITypeGetOffsetInBits(DType); in llvm_di_type_get_offset_in_bits() 828 value llvm_di_type_get_align_in_bits(LLVMMetadataRef DType) { in llvm_di_type_get_align_in_bits() argument 829 uint32_t Size = LLVMDITypeGetAlignInBits(DType); in llvm_di_type_get_align_in_bits() 833 value llvm_di_type_get_line(LLVMMetadataRef DType) { in llvm_di_type_get_line() argument 834 unsigned Line = LLVMDITypeGetLine(DType); in llvm_di_type_get_line() 838 value llvm_di_type_get_flags(LLVMMetadataRef DType) { in llvm_di_type_get_flags() argument [all …]
|
| /llvm-project-15.0.7/llvm/include/llvm-c/ |
| H A D | DebugInfo.h | 1035 const char *LLVMDITypeGetName(LLVMMetadataRef DType, size_t *Length); 1043 uint64_t LLVMDITypeGetSizeInBits(LLVMMetadataRef DType); 1051 uint64_t LLVMDITypeGetOffsetInBits(LLVMMetadataRef DType); 1059 uint32_t LLVMDITypeGetAlignInBits(LLVMMetadataRef DType); 1067 unsigned LLVMDITypeGetLine(LLVMMetadataRef DType); 1075 LLVMDIFlags LLVMDITypeGetFlags(LLVMMetadataRef DType);
|
| /llvm-project-15.0.7/mlir/test/Integration/Dialect/SparseTensor/taco/ |
| H A D | unit_test_tensor_core.py | 50 passed = mlir_pytaco.DType(mlir_pytaco.Type.INT16).is_int() 51 passed += mlir_pytaco.DType(mlir_pytaco.Type.INT32).is_int() 52 passed += mlir_pytaco.DType(mlir_pytaco.Type.INT64).is_int() 53 passed += mlir_pytaco.DType(mlir_pytaco.Type.FLOAT32).is_float() 54 passed += mlir_pytaco.DType(mlir_pytaco.Type.FLOAT64).is_float()
|
| /llvm-project-15.0.7/llvm/lib/IR/ |
| H A D | DebugInfo.cpp | 1393 StringRef Str = unwrap<DIType>(DType)->getName(); in LLVMDITypeGetName() 1398 uint64_t LLVMDITypeGetSizeInBits(LLVMMetadataRef DType) { in LLVMDITypeGetSizeInBits() argument 1399 return unwrapDI<DIType>(DType)->getSizeInBits(); in LLVMDITypeGetSizeInBits() 1402 uint64_t LLVMDITypeGetOffsetInBits(LLVMMetadataRef DType) { in LLVMDITypeGetOffsetInBits() argument 1403 return unwrapDI<DIType>(DType)->getOffsetInBits(); in LLVMDITypeGetOffsetInBits() 1406 uint32_t LLVMDITypeGetAlignInBits(LLVMMetadataRef DType) { in LLVMDITypeGetAlignInBits() argument 1407 return unwrapDI<DIType>(DType)->getAlignInBits(); in LLVMDITypeGetAlignInBits() 1410 unsigned LLVMDITypeGetLine(LLVMMetadataRef DType) { in LLVMDITypeGetLine() argument 1411 return unwrapDI<DIType>(DType)->getLine(); in LLVMDITypeGetLine() 1414 LLVMDIFlags LLVMDITypeGetFlags(LLVMMetadataRef DType) { in LLVMDITypeGetFlags() argument [all …]
|
| /llvm-project-15.0.7/clang/lib/Frontend/ |
| H A D | VerifyDiagnosticConsumer.cpp | 456 StringRef DType; in ParseDirective() local 457 if (DToken.endswith(DType="-error")) in ParseDirective() 459 else if (DToken.endswith(DType="-warning")) in ParseDirective() 461 else if (DToken.endswith(DType="-remark")) in ParseDirective() 463 else if (DToken.endswith(DType="-note")) in ParseDirective() 465 else if (DToken.endswith(DType="-no-diagnostics")) { in ParseDirective() 472 DToken = DToken.substr(0, DToken.size()-DType.size()); in ParseDirective()
|
| /llvm-project-15.0.7/llvm/lib/CodeGen/ |
| H A D | JMCInstrumenter.cpp | 110 auto *DType = in attachDebugInfo() local 116 /*LineNo=*/0, DType, /*IsLocalToUnit=*/true, /*IsDefined=*/true); in attachDebugInfo()
|
| /llvm-project-15.0.7/mlir/lib/Target/SPIRV/Serialization/ |
| H A D | Serializer.h | 140 template <typename DType> 141 LogicalResult processTypeDecoration(Location loc, DType type, in processTypeDecoration()
|
| /llvm-project-15.0.7/llvm/lib/Target/AArch64/ |
| H A D | AArch64ExpandPseudoInsts.cpp | 443 uint64_t DType = TII->get(Opcode).TSFlags & AArch64::DestructiveInstTypeMask; in expand_DestructiveOp() local 450 if (DType == AArch64::DestructiveBinary) in expand_DestructiveOp() 455 switch (DType) { in expand_DestructiveOp() 493 switch (DType) { in expand_DestructiveOp() 584 switch (DType) { in expand_DestructiveOp()
|
| /llvm-project-15.0.7/llvm/lib/TableGen/ |
| H A D | TGParser.cpp | 1024 DagRecTy *DType = dyn_cast<DagRecTy>(LHSt->getType()); in ParseOperation() local 1025 if (!LType && !SType && !DType) { in ParseOperation()
|
| /llvm-project-15.0.7/clang/lib/CodeGen/ |
| H A D | CGBuiltin.cpp | 18200 llvm::Type *DType = Dst.getElementType(); in EmitNVPTXBuiltinExpr() local 18203 Builder.CreateBitCast(Builder.CreateExtractValue(Result, i), DType), in EmitNVPTXBuiltinExpr()
|